Crate rusty_dns

DNS implementation in Rust with no dependencies other than Rand
See DNS RFC Notes for notes on DNS protocols.

Modules

  • CLASS values, all of which are a subset of QCLASS values.
  • DNS packet structures and operations.
  • DNS Domain Name operations.
  • DNS OPCODE values.
  • QCLASS values, used in the question section of a DNS packet.
  • QTYPE values, used in the question section of a DNS packet.
  • Example DNS query packets in network format
  • RCODE values.
  • TYPE values, all of which are a subset of QTYPE values.

Constants

Functions